pub enum AstError {
ParseError(ParseError),
CircularImport(PathBuf),
ImportFailed(PathBuf),
}Expand description
A common error type for all of the things that can go wrong while parsing and building the AST
See AstResult
Variants