pub struct Formula { /* private fields */ }Implementations
Sourceimpl Formula
impl Formula
pub fn new(clauses: BTreeSet<Clause>, shared: BTreeSet<Clause>) -> Self
pub fn with_clause(clause: Clause) -> Self
pub fn with_clauses(clauses: impl IntoIterator<Item = Clause>) -> Self
pub fn is_empty(&self) -> bool
pub fn first(&self) -> &Clause
pub fn is_subset(&self, other: &Formula) -> bool
pub fn into_inner(self) -> (BTreeSet<Clause>, BTreeSet<Clause>)
pub fn elements(&self) -> &BTreeSet<Clause>
pub fn merge(self, other: Formula) -> Self
pub fn len(&self) -> usize
Sourcepub fn normalize(self) -> Self
pub fn normalize(self) -> Self
Normalize a formula.
For any formula, we define a normal form which exists, is unique, and is equivalent to the original formula under the usual interpretation of boolean logic.
Clauses are always normal, since all literals are positive. Formulae are normalized by removing any clause subsumed by any other. A clause c is subsumed by a clause s if s <= c. This is the obvious O(mn) algorithm. Our formulae are usually of size 1, so this is just fine.